@@ -4,10 +4,8 @@
 from bs4 import BeautifulSoup
 from datetime import date as dt
 import os
-from pyvirtualdisplay import Display
 import re
 import requests
-from selenium import webdriver
 import sys
 import time
 
@@ -28,6 +26,7 @@ class Comunio:
         self.password = password
         self.domain = Leagues[league]
         self.session = requests.session()
+        self.login()
 
     def login(self):
         payload = { 'login':self.username,
@@ -35,14 +34,14 @@ class Comunio:
                     'action':'login'}
         headers = {"Content-type": "application/x-www-form-urlencoded","Accept": "text/plain","User-Agent": user_agent}
         req = self.session.post('http://'+self.domain+'/login.phtml',headers=headers,data=payload).content
-        #soup = BeautifulSoup(req)
-        if 'puntos en proceso' in req:
+        if 'puntos en proceso' in req or 'points in process' in req:
             print 'Comunio webpage not available.'
-            sys.exit(1)
+            return
+
         self.load_info() #Function to load the account information
   
     def load_info(self):
-        ''' Get info from account logged '''
+        ''' Get info from logged account '''
         headers = {"Content-type": "application/x-www-form-urlencoded","Accept": "text/plain",'Referer': 'http://'+self.domain+'/login.phtml',"User-Agent": user_agent}
         req = self.session.get('http://'+self.domain+'/team_news.phtml',headers=headers).content
         soup = BeautifulSoup(req)
@@ -51,13 +50,15 @@ class Comunio:
         estado = soup.find('div',{'id':'content'}).find('div',{'id':'manager'}).string
         if estado:
             print estado.strip()
-            sys.exit(1)
-            
+            return
+
         [s.extract() for s in soup('strong')]
         if (soup.find('div',{'id':'userid'}) != None):
-            self.id = soup.find('div',{'id':'userid'}).p.text.strip()[2:]
+            self.myid = soup.find('div',{'id':'userid'}).p.text.strip()[2:]
             self.money = int(soup.find('div',{'id':'manager_money'}).p.text.strip().replace(".","")[:-2])
             self.teamvalue = int(soup.find('div',{'id':'teamvalue'}).p.text.strip().replace(".","")[:-2])
+            self.community_id = soup.find('link')['href'][24:]
+            self.username = soup.find('div',{'id':'username'}).p.a.text
 
     def get_money(self):
         '''Get my money'''
@@ -69,11 +70,15 @@ class Comunio:
     
     def get_myid(self):
         '''Get my id'''
-        return self.id
+        return self.myid
     
     def get_title(self):
         '''Title of the webpage'''
         return self.title
+    
+    def get_username(self):
+        '''Name of the user'''
+        return self.username
 
     def get_news(self):
         '''Get all the news from first page'''
@@ -166,6 +171,7 @@ class Comunio:
 
     def info_player_id(self,name):
         '''Get id using name football player'''
+        number = 0
         name=name.title().replace(" ", "+")
         headers = {"Content-type": "application/x-www-form-urlencoded","Accept": "text/plain",'Referer': 'http://'+self.domain+'/team_news.phtml',"User-Agent": user_agent}
         req = self.session.get('http://stats.comunio.es/search.php?name='+name,headers=headers).content
@@ -227,66 +233,35 @@ class Comunio:
         return None
 
 
-    def players_onsale(self, only_computer=False):
+    def players_onsale(self, community_id, only_computer=False):
         '''
         Returns the football players currently on sale
         @return: [[name, team, min_price, market_price, points, date, owner, position]]
         '''
-        reintentos=0
+        headers = {"Content-type": "application/x-www-form-urlencoded","Accept": "text/plain",'Referer': 'http://'+self.domain+'/team_news.phtml',"User-Agent": user_agent}
+        req = self.session.get('http://'+self.domain+'/teamInfo.phtml?tid=' + community_id, headers=headers).content
+        soup = BeautifulSoup(req)
+        
         current_year = dt.today().year
         current_month = dt.today().month
-        display = Display(visible=0, size=(800, 600))
-        display.start()
-        xpaths = { 'usernameTxtBox':   ".//*[@id='login-ubox']/input",
-                   'passwordTxtBox':   ".//*[@id='login-pwbox']/input",
-                   'loginButton'   :   ".//*[@id='login-box-wrapper']/a",
-                   'exchange_table':   ".//*[@id='searchTextResults']"
-                   }
-        browser = webdriver.Firefox()
-        browser.get("http://www.comunio.es/login.phtml")
-        browser.find_element_by_xpath(xpaths['usernameTxtBox']).clear()
-        browser.find_element_by_xpath(xpaths['usernameTxtBox']).send_keys(self.username)
-        browser.find_element_by_xpath(xpaths['passwordTxtBox']).clear()
-        browser.find_element_by_xpath(xpaths['passwordTxtBox']).send_keys(self.password)
-        browser.find_element_by_xpath(xpaths['loginButton']).click()
-        time.sleep(3)
-        # Esperaremos en el while hasta que termine de cargar el JS de la página
-        browser.get('http://www.comunio.es/exchangemarket.phtml')
-        time.sleep(3)
-        while True and reintentos < 20:
-            req = browser.page_source
-            soup = BeautifulSoup(req)
-            on_sale = []
-            year_flag = 0
-            try:
-                for i in soup.find('table',{'class','tablecontent03'}).find_all('tr')[2:]:
-                    name = i.find_all('td')[0].text.strip()
-                    team = i.find('span')['title']
-                    min_price = i.find_all('td')[2].text.replace(",","").strip()
-                    market_price = i.find_all('td')[3].text.replace(",","").strip()
-                    points = i.find_all('td')[4].text.strip().strip()
-                    # Controlamos el cambio de año, ya que comunio no lo dá
-                    if current_month <= 7 and int(i.find_all('td')[5].text[3:5]) > 7:
-                        year_flag = 1
-                    date = str(current_year-year_flag)+i.find_all('td')[5].text[3:5]+i.find_all('td')[5].text[:2]
-                    owner = i.find_all('td')[6].text.strip()
-                    position = i.find_all('td')[7].text.strip()
-                    # Comprobamos si solamente queremos los de la computadora o no
-                    if (only_computer and owner == 'Computer') or not only_computer:
-                        on_sale.append([name, team, min_price, market_price, points, date, owner, position])
-                # Llegaremos al break cuando se haya cargado el JS y cargado la lista
-                if on_sale != []:
-                    break
-            except Exception as e:
-                reintentos+=1
-                print 'Error looking for players on sale "players_onsale": ', e
-                print 'Trying again (%s).' % reintentos
-                if reintentos == 10:
-                    browser.get('http://www.comunio.es/exchangemarket.phtml')
-                time.sleep(3)
-        
-        browser.quit()
-        display.stop()
+        on_sale = []
+        year_flag = 0
+        for i in soup.find_all('table',{'class','tablecontent03'})[2].find_all('tr')[1:]:
+            name = i.find_all('td')[0].text.strip()
+            team = i.find('img')['alt']
+            min_price = i.find_all('td')[2].text.replace(".","").strip()
+            market_price = i.find_all('td')[3].text.replace(".","").strip()
+            points = i.find_all('td')[4].text.strip().strip()
+            # Controlamos el cambio de año, ya que comunio no lo dá
+            if current_month <= 7 and int(i.find_all('td')[5].text[3:5]) > 7:
+                year_flag = 1
+            date = str(current_year-year_flag)+i.find_all('td')[5].text[3:5]+i.find_all('td')[5].text[:2]
+            owner = i.find_all('td')[6].text.strip()
+            position = i.find_all('td')[7].text.strip()
+            # Comprobamos si solamente queremos los de la computadora o no
+            if (only_computer and owner == 'Computer') or not only_computer:
+                on_sale.append([name, team, min_price, market_price, points, date, owner, position])
+
         return on_sale
 
 
